@@ -1,9 +1,6 @@
 "getgrid.gp" <-
 function(object,...){
   # return the implicit grid of the process as two columns, the first the grid values in the x-direction and the second in the y-direction
-  if(!is.gp(object)){
-    stop(" 'object' argument must be of class 'gp' ")
-  }
   m1=object$gridsize[1]
   m2=object$gridsize[2]
   if(object$d==2){
